import { useCallback, useState } from "react";
import { Typography } from "@mui/material";
import {
  SimpleAccordion,
  InternalLink,
  EmptyValue
} from "@ess-ics/ce-ui-common";
import { IOCDetails } from "../IOCDetails";
import { LokiPanel } from "../../common/Loki/LokiPanel";
import { RecordSearch } from "../../records/RecordSearch";
import { GitRefLink } from "../../common/Git/GitRefLink";
import AccessControl from "../../auth/AccessControl";

export function IOCLiveStatus({ ioc }) {
  const [accordionState, setAccordionState] = useState({
    logStreamOpen: false,
    recordsOpen: false
  });

  const hostName = ioc.activeDeployment?.host?.hostName;
  const externalIdValid = ioc.activeDeployment?.host?.externalIdValid;

  const getSubset = useCallback((ioc) => {
    let subset = {
      Description: ioc.description,
      Revision: ioc.activeDeployment ? (
        <GitRefLink
          url={ioc.activeDeployment?.sourceUrl}
          displayReference={ioc.activeDeployment?.sourceVersion}
          revision={ioc.activeDeployment?.sourceVersion}
        />
      ) : (
        <EmptyValue />
      ),
      "Deployed on":
        ioc.activeDeployment && ioc.activeDeployment?.host.externalIdValid ? (
          <Typography>
            {ioc.activeDeployment?.host.hostId ? (
              <InternalLink
                to={`/hosts/${ioc.activeDeployment?.host.hostId}`}
                label={`Host details, ${ioc.activeDeployment?.host.fqdn}`}
              >
                {ioc.activeDeployment?.host.fqdn}
              </InternalLink>
            ) : (
              ioc.activeDeployment?.host.fqdn
            )}
          </Typography>
        ) : (
          <EmptyValue />
        )
    };

    return subset;
  }, []);

  return (
    <>
      <IOCDetails
        ioc={ioc}
        getSubset={getSubset}
      />

      <AccessControl
        allowedRoles={["DeploymentToolAdmin", "DeploymentToolIntegrator"]}
        renderNoAccess={() => <></>}
      >
        {externalIdValid && (
          <SimpleAccordion
            summary={
              <Typography
                component="h2"
                variant="h3"
              >
                IOC log stream
              </Typography>
            }
            expanded={accordionState.logStreamOpen}
            onChange={(_, expanded) =>
              setAccordionState({ ...accordionState, logStreamOpen: expanded })
            }
          >
            {hostName && (
              <LokiPanel
                hostName={hostName}
                iocName={ioc.namingName}
              />
            )}
          </SimpleAccordion>
        )}
        <SimpleAccordion
          summary={
            <Typography
              component="h2"
              variant="h3"
            >
              Records
            </Typography>
          }
          expanded={accordionState.recordsOpen}
          onChange={(_, expanded) =>
            setAccordionState({ ...accordionState, recordsOpen: expanded })
          }
        >
          <RecordSearch
            iocName={ioc.namingName}
            rowType="iocDetails"
          />
        </SimpleAccordion>
      </AccessControl>
    </>
  );
}
